==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/BridgeArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgument;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.List;


public class BridgeArgumentSetImpl extends InstanceSet<BridgeArgumentSet,BridgeArgument> implements BridgeArgumentSet {

    // attributes
    @Override
    public void setBParm_ID( UniqueId ref_BParm_ID ) throws XtumlException {
        for ( BridgeArgument bridgeargument : this ) bridgeargument.setBParm_ID( ref_BParm_ID );
    }
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( BridgeArgument bridgeargument : this ) bridgeargument.setArg_ID( ref_Arg_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( BridgeArgument bridgeargument : this ) messageargumentset.add( bridgeargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public BridgeParameterSet R1014_is_represented_by_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( BridgeArgument bridgeargument : this ) bridgeparameterset.add( bridgeargument.R1014_is_represented_by_BridgeParameter() );
        return bridgeparameterset;
    }


    @Override
    public BridgeArgument nullElement() {
        return BridgeArgumentImpl.EMPTY_BRIDGEARGUMENT;
    }

    @Override
    public BridgeArgumentSet emptySet() {
      return new BridgeArgumentSetImpl();
    }

    @Override
    public BridgeArgumentSet value() {
        return this;
    }

    @Override
    public List<BridgeArgument> elements() {
        return Arrays.asList(toArray(new BridgeArgument[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/message/impl/BridgeArgumentSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.message.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.domain.BridgeParameterSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.BridgeParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgument;
import io.ciera.tool.sql.ooaofooa.message.BridgeArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.MessageArgumentSet;
import io.ciera.tool.sql.ooaofooa.message.impl.MessageArgumentSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class BridgeArgumentSetImpl extends InstanceSet<BridgeArgumentSet,BridgeArgument> implements BridgeArgumentSet {

    public BridgeArgumentSetImpl() {
    }

    public BridgeArgumentSetImpl(Comparator<? super BridgeArgument> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setArg_ID( UniqueId ref_Arg_ID ) throws XtumlException {
        for ( BridgeArgument bridgeargument : this ) bridgeargument.setArg_ID( ref_Arg_ID );
    }
    @Override
    public void setBParm_ID( UniqueId ref_BParm_ID ) throws XtumlException {
        for ( BridgeArgument bridgeargument : this ) bridgeargument.setBParm_ID( ref_BParm_ID );
    }


    // selections
    @Override
    public MessageArgumentSet R1013_is_a_MessageArgument() throws XtumlException {
        MessageArgumentSet messageargumentset = new MessageArgumentSetImpl();
        for ( BridgeArgument bridgeargument : this ) messageargumentset.add( bridgeargument.R1013_is_a_MessageArgument() );
        return messageargumentset;
    }
    @Override
    public BridgeParameterSet R1014_is_represented_by_BridgeParameter() throws XtumlException {
        BridgeParameterSet bridgeparameterset = new BridgeParameterSetImpl();
        for ( BridgeArgument bridgeargument : this ) bridgeparameterset.add( bridgeargument.R1014_is_represented_by_BridgeParameter() );
        return bridgeparameterset;
    }


    @Override
    public BridgeArgument nullElement() {
        return BridgeArgumentImpl.EMPTY_BRIDGEARGUMENT;
    }

    @Override
    public BridgeArgumentSet emptySet() {
      return new BridgeArgumentSetImpl();
    }

    @Override
    public BridgeArgumentSet emptySet(Comparator<? super BridgeArgument> comp) {
      return new BridgeArgumentSetImpl(comp);
    }

    @Override
    public BridgeArgumentSet value() {
        return this;
    }

    @Override
    public List<BridgeArgument> elements() {
        return Arrays.asList(toArray(new BridgeArgument[0]));
    }

}
